import betamax
import requests

CASSETTE_LIBRARY_DIR = 'examples/cassettes/'


def main():
    session = requests.Session()
    recorder = betamax.Betamax(
        session, cassette_library_dir=CASSETTE_LIBRARY_DIR
    )

    with recorder.use_cassette('our-first-recorded-session'):
        session.get('https://httpbin.org/get')


if __name__ == '__main__':
    main()



import unittest
import inspect

from betamax import exceptions


def exception_classes():
    for _, module_object in inspect.getmembers(exceptions):
        if inspect.isclass(module_object):
            yield module_object


class TestExceptions(unittest.TestCase):
    def test_all_exceptions_are_betamax_errors(self):
        for exception_class in exception_classes():
            assert isinstance(exception_class('msg'), exceptions.BetamaxError)

    def test_all_validation_errors_are_in_validation_error_map(self):
        validation_error_map_values = exceptions.validation_error_map.values()
        for exception_class in exception_classes():
            if exception_class.__name__ == 'ValidationError' or \
               not exception_class.__name__.endswith('ValidationError'):
                continue
            assert exception_class in validation_error_map_values

    def test_all_validation_errors_are_validation_errors(self):
        for exception_class in exception_classes():
            if not exception_class.__name__.endswith('ValidationError'):
                continue
            assert isinstance(exception_class('msg'),
                              exceptions.ValidationError)

    def test_invalid_option_is_validation_error(self):
        assert isinstance(exceptions.InvalidOption('msg'),
                          exceptions.ValidationError)

    def test_betamaxerror_repr(self):
        """Ensure errors don't raise exceptions in their __repr__.

        This should protect against regression. If this test starts failing,
        heavily modify it to not be flakey.
        """
        assert "BetamaxError" in repr(exceptions.BetamaxError('test'))



import betamax
import requests

CASSETTE_LIBRARY_DIR = 'examples/record_modes/none/'


def main():
    session = requests.Session()
    recorder = betamax.Betamax(
        session, cassette_library_dir=CASSETTE_LIBRARY_DIR
    )

    with recorder.use_cassette('none-example', record='none'):
        session.get('https://httpbin.org/get')
        session.post('https://httpbin.org/post',
                     params={'id': '20'},
                     json={'some-attribute': 'some-value'})
        session.get('https://httpbin.org/get', params={'id': '20'})


if __name__ == '__main__':
    main()



import os
import unittest

import pytest
import requests

from betamax import Betamax


class TestRequests211BodyMatcher(unittest.TestCase):
    def tearDown(self):
        os.unlink('tests/cassettes/requests_2_11_body_matcher.json')

    @pytest.mark.skipif(requests.__build__ < 0x020401,
                        reason="No json keyword.")
    def test_requests_with_json_body(self):
        s = requests.Session()
        with Betamax(s).use_cassette('requests_2_11_body_matcher',
                                     match_requests_on=['body']):
            r = s.post('https://httpbin.org/post', json={'a': 2})
            assert r.json() is not None

        s = requests.Session()
        with Betamax(s).use_cassette('requests_2_11_body_matcher',
                                     match_requests_on=['body']):
            r = s.post('https://httpbin.org/post', json={'a': 2})
            assert r.json() is not None



import os.path

import pytest


@pytest.mark.usefixtures('betamax_session')
class TestPyTestFixtures:
    @pytest.fixture(autouse=True)
    def setup(self, request):
        """After test hook to assert everything."""
        def finalizer():
            test_dir = os.path.abspath('.')
            cassette_name = ('tests.integration.test_fixtures.'  # Module name
                             'TestPyTestFixtures.'  # Class name
                             'test_pytest_fixture'  # Test function name
                             '.json')
            file_name = os.path.join(test_dir, 'tests', 'cassettes',
                                     cassette_name)
            assert os.path.exists(file_name) is True

        request.addfinalizer(finalizer)

    def test_pytest_fixture(self, betamax_session):
        """Exercise the fixture itself."""
        resp = betamax_session.get('https://httpbin.org/get')
        assert resp.ok


@pytest.mark.usefixtures('betamax_parametrized_session')
class TestPyTestParametrizedFixtures:
    @pytest.fixture(autouse=True)
    def setup(self, request):
        """After test hook to assert everything."""
        def finalizer():
            test_dir = os.path.abspath('.')
            cassette_name = ('tests.integration.test_fixtures.'  # Module name
                             'TestPyTestParametrizedFixtures.'  # Class name
                             'test_pytest_fixture'  # Test function name
                             '[https---httpbin.org-get]'  # Parameter
                             '.json')
            file_name = os.path.join(test_dir, 'tests', 'cassettes',
                                     cassette_name)
            assert os.path.exists(file_name) is True

        request.addfinalizer(finalizer)

    @pytest.mark.parametrize('url', ('https://httpbin.org/get',))
    def test_pytest_fixture(self, betamax_parametrized_session, url):
        """Exercise the fixture itself."""
        resp = betamax_parametrized_session.get(url)
        assert resp.ok


@pytest.mark.parametrize('problematic_arg', [r'aaa\bbb', 'ccc:ddd', 'eee*fff'])
def test_pytest_parametrize_with_filesystem_problematic_chars(
        betamax_parametrized_session, problematic_arg):
    """
    Exercice parametrized args containing characters which might cause
    problems when getting translated into file names. """
    assert True



import betamax
from betamax_serializers import pretty_json
import requests

CASSETTE_LIBRARY_DIR = 'examples/cassettes/'


def main():
    session = requests.Session()
    betamax.Betamax.register_serializer(pretty_json.PrettyJSONSerializer)
    recorder = betamax.Betamax(
        session, cassette_library_dir=CASSETTE_LIBRARY_DIR
    )
    matchers = ['method', 'uri', 'body']

    with recorder.use_cassette('more-complicated-cassettes',
                               serialize_with='prettyjson',
                               match_requests_on=matchers):
        session.get('https://httpbin.org/get')
        session.post('https://httpbin.org/post',
                     params={'id': '20'},
                     json={'some-attribute': 'some-value'})
        session.get('https://httpbin.org/get', params={'id': '20'})
        session.post('https://httpbin.org/post',
                     params={'id': '20'},
                     json={'some-other-attribute': 'some-other-value'})


if __name__ == '__main__':
    main()
